<?php declare(strict_types=1);

namespace App\Form;

use App\Entity\MenuItem;
use App\Repository\MenuItemRepository;
use Doctrine\ORM\QueryBuilder;
use Override;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Bridge\Doctrine\Types\UlidType;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;

final class MenuItemType extends AbstractType
{
    #[Override]
    public function buildForm(FormBuilderInterface $builder, array $options): void
    {
        $vendor = $options['data']->getFoodVendor();
        $vendorId = $vendor->getId();
        $builder
            ->add('name')
            ->add('aliasOf', EntityType::class, [
                'class' => MenuItem::class,
                'choice_label' => 'name',
                'query_builder' => static fn(MenuItemRepository $repository): QueryBuilder => $repository
                    ->createQueryBuilder('m')
                    ->where('m.foodVendor = :vendorId')
                    ->setParameter(':vendorId', $vendorId, UlidType::NAME),
            ])
        ;
    }

    #[Override]
    public function configureOptions(OptionsResolver $resolver): void
    {
        $resolver->setDefaults([
            'data_class' => MenuItem::class,
        ]);
    }
}
